summaryrefslogtreecommitdiffhomepage
path: root/message.py
diff options
context:
space:
mode:
authorRobey Pointer <robey@lag.net>2003-11-10 08:49:50 +0000
committerRobey Pointer <robey@lag.net>2003-11-10 08:49:50 +0000
commit11815d4d837314a51ebf919c1a61cb0f68a3c02b (patch)
treea87cdf5a7f3658375d0d6be642a5d8ddf46bbc36 /message.py
parent2ff9f467517e1ff8916e1adbdaf342d0468b4ebb (diff)
[project @ Arch-1:robey@lag.net--2003-public%secsh--dev--1.0--patch-9]
rename secsh -> paramiko also, rename SecshException back to SSHException. sigh. :)
Diffstat (limited to 'message.py')
-rw-r--r--message.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/message.py b/message.py
index aeccd9f4..0660fe63 100644
--- a/message.py
+++ b/message.py
@@ -1,11 +1,11 @@
# implementation of a secsh "message"
import string, types, struct
from util import inflate_long, deflate_long
class Message(object):
- "represents the encoding of a secsh message"
+ "represents the encoding of an SSH2 message"
def __init__(self, content=''):
self.packet = content
@@ -1,11 +1,11 @@
-# implementation of a secsh "message"
+# implementation of an SSH2 "message"
import string, types, struct
from util import inflate_long, deflate_long